@@ -6,24 +6,18 @@
 #' @return A summarised_result object.
 #' @export
 #' @examples
-#' \donttest{
-#' library(OmopSketch)
 #' cdm <- mockOmopSketch(numberIndividuals = 10)
 #'
 #' summariseOmopSnapshot(cdm)
-#' }
 summariseOmopSnapshot <- function(cdm) {
 
-  omopgenerics::validateCdmArgument(cdm)
+  cdm <- omopgenerics::validateCdmArgument(cdm)
 
   summaryTable <- summary(cdm)
 
   summaryTable <- summaryTable |>
     internalTibble() |>
-    omopgenerics::newSummarisedResult(settings = dplyr::tibble(
-      result_id = unique(summaryTable$result_id),
-      package_name = "omopSketch",
-      package_version = as.character(utils::packageVersion("OmopSketch")),
+    omopgenerics::newSummarisedResult(settings = createSettings(
       result_type = "summarise_omop_snapshot"
     ))
 
