@@ -13,10 +13,11 @@ test_that("summariseClinicalRecords() works", {
   expect_warning(summariseClinicalRecords(cdm, "device_exposure"))
   expect_no_error(m <- summariseClinicalRecords(cdm, "measurement"))
   expect_no_error(summariseClinicalRecords(cdm, "observation"))
-  expect_warning(summariseClinicalRecords(cdm, "death"))
+  expect_warning(de<-summariseClinicalRecords(cdm, "death"))
 
   #Check result type
   checkResultType(op, "summarise_clinical_records")
+  checkResultType(de, "summarise_clinical_records")
 
   expect_no_error(all <- summariseClinicalRecords(cdm, c("observation_period", "visit_occurrence", "measurement")))
   expect_equal(
@@ -120,18 +121,39 @@ test_that("summariseClinicalRecords() sex and ageGroup argument work", {
   x <- cdm[["measurement"]] |>
     PatientProfiles::addAgeQuery(indexDate = "measurement_date", ageGroup = list(">= 30" = c(30, Inf), "<30" = c(0, 29))) |>
     dplyr::select("person_id", "age_group")
-  n_records  <- x |> dplyr::group_by(age_group) |> dplyr::summarise(estimate_value = dplyr::n()) |> dplyr::collect() |> dplyr::arrange(age_group) |> dplyr::mutate(dplyr::across(dplyr::everything(), as.character))
-  n_subjects <- x |> dplyr::group_by(person_id,age_group) |> dplyr::ungroup() |> dplyr::distinct() |> dplyr::group_by(age_group) |> dplyr::summarise(estimate_value = dplyr::n()) |> dplyr::collect() |> dplyr::arrange(age_group) |> dplyr::mutate(dplyr::across(dplyr::everything(), as.character))
+  n_records  <- x |>
+    dplyr::group_by(age_group) |>
+    dplyr::summarise(estimate_value = dplyr::n()) |>
+    dplyr::collect() |>
+    dplyr::arrange(age_group) |>
+    dplyr::mutate(dplyr::across(dplyr::everything(), as.character))
+  n_subjects <- x |>
+    dplyr::group_by(person_id,age_group) |>
+    dplyr::ungroup() |>
+    dplyr::distinct() |>
+    dplyr::group_by(age_group) |>
+    dplyr::summarise(estimate_value = dplyr::n()) |>
+    dplyr::collect() |>
+    dplyr::arrange(age_group) |>
+    dplyr::mutate(dplyr::across(dplyr::everything(), as.character))
 
-  m_records  <- m |> dplyr::filter(variable_name == "number records", strata_level %in% c("<30", ">= 30"), estimate_name == "count")  |> dplyr::select("age_group" = "strata_level", "estimate_value") |> dplyr::collect() |> dplyr::arrange(age_group)
-  m_subjects <- m |> dplyr::filter(variable_name == "number subjects", strata_level %in% c("<30", ">= 30"), estimate_name == "count") |> dplyr::select("age_group" = "strata_level", "estimate_value") |> dplyr::collect() |> dplyr::arrange(age_group)
+  m_records  <- m |>
+    dplyr::filter(variable_name == "Number records", strata_level %in% c("<30", ">= 30"), estimate_name == "count") |>
+    dplyr::select("age_group" = "strata_level", "estimate_value") |>
+    dplyr::collect() |>
+    dplyr::arrange(age_group)
+  m_subjects <- m |>
+    dplyr::filter(variable_name == "Number subjects", strata_level %in% c("<30", ">= 30"), estimate_name == "count") |>
+    dplyr::select("age_group" = "strata_level", "estimate_value") |>
+    dplyr::collect() |>
+    dplyr::arrange(age_group)
 
-  expect_equal(list(m_records$age_group,  m_records$estimate_value),   list(n_records$age_group, n_records$estimate_value))
-  expect_equal(list(m_subjects$age_group, m_subjects$estimate_value), list(n_subjects$age_group, n_subjects$estimate_value))
+  expect_equal(m_records, n_records, ignore_attr = TRUE)
+  expect_equal(m_subjects, n_subjects, ignore_attr = TRUE)
 
   # Check sex and age group---
   x <- summariseClinicalRecords(cdm, "condition_occurrence", sex = TRUE, ageGroup = list(">= 30" = c(30, Inf), "<30" = c(0, 29))) |>
-    dplyr::filter(variable_name == "number subjects", estimate_name == "count",
+    dplyr::filter(variable_name == "Number subjects", estimate_name == "count",
                   strata_name == "sex" | strata_name == "overall") |>
     dplyr::select("strata_name", "strata_level", "estimate_value") |>
     dplyr::mutate(group = dplyr::if_else(strata_name == "overall",1, 2)) |>
@@ -140,7 +162,7 @@ test_that("summariseClinicalRecords() sex and ageGroup argument work", {
   expect_equal(x$n[[1]], x$n[[2]])
 
   x <- summariseClinicalRecords(cdm, "condition_occurrence", sex = TRUE, ageGroup = list(">= 30" = c(30, Inf), "<30" = c(0, 29))) |>
-    dplyr::filter(variable_name == "number records", estimate_name == "count",
+    dplyr::filter(variable_name == "Number records", estimate_name == "count",
                   strata_name == "sex" | strata_name == "overall") |>
     dplyr::select("strata_name", "strata_level", "estimate_value") |>
     dplyr::mutate(group = dplyr::if_else(strata_name == "overall",1, 2)) |>
@@ -149,7 +171,7 @@ test_that("summariseClinicalRecords() sex and ageGroup argument work", {
   expect_equal(x$n[[1]], x$n[[2]])
 
   x <- summariseClinicalRecords(cdm, "condition_occurrence", sex = TRUE, ageGroup = list(">= 30" = c(30, Inf), "<30" = c(0, 29))) |>
-    dplyr::filter(variable_name == "number records", estimate_name == "count",
+    dplyr::filter(variable_name == "Number records", estimate_name == "count",
                   strata_name == "age_group" | strata_name == "overall") |>
     dplyr::select("strata_name", "strata_level", "estimate_value") |>
     dplyr::mutate(group = dplyr::if_else(strata_name == "overall",1, 2)) |>
@@ -193,18 +215,21 @@ test_that("summariseClinicalRecords() sex and ageGroup argument work", {
   cdm <- CDMConnector::copyCdmTo(
     con = connection(), cdm = cdm, schema = schema())
 
-  result <- summariseClinicalRecords(cdm, "observation_period",
-                           inObservation = FALSE,
-                           standardConcept = FALSE,
-                           sourceVocabulary = FALSE,
-                           domainId = FALSE,
-                           typeConcept = FALSE,
-                           sex = TRUE,
-                           ageGroup = list("old" = c(10, Inf), "young" = c(0, 9)))
+  result <- summariseClinicalRecords(
+    cdm = cdm,
+    omopTableName = "observation_period",
+    inObservation = FALSE,
+    standardConcept = FALSE,
+    sourceVocabulary = FALSE,
+    domainId = FALSE,
+    typeConcept = FALSE,
+    sex = TRUE,
+    ageGroup = list("old" = c(10, Inf), "young" = c(0, 9))
+  )
 
   # Check num records
   records <- result |>
-    dplyr::filter(variable_name == "number records", estimate_name == "count")
+    dplyr::filter(variable_name == "Number records", estimate_name == "count")
   expect_identical(records |> dplyr::filter(strata_name == "overall") |> dplyr::pull(estimate_value), "9")
   expect_identical(records |> dplyr::filter(strata_level == "old") |> dplyr::pull(estimate_value), "5")
   expect_identical(records |> dplyr::filter(strata_level == "young") |> dplyr::pull(estimate_value), "4")
@@ -218,10 +243,46 @@ test_that("summariseClinicalRecords() sex and ageGroup argument work", {
   # Check stats
   records <- result |>
     dplyr::filter(variable_name == "records_per_person")
-  expect_true(records |> dplyr::filter(strata_name == "overall", estimate_name == "mean") |> dplyr::pull(estimate_value) == "1.8")
+  expect_true(records |> dplyr::filter(strata_name == "overall", estimate_name == "mean") |> dplyr::pull(estimate_value) == "1.8000")
   expect_true(records |> dplyr::filter(strata_level == "old &&& Male", estimate_name == "median") |> dplyr::pull(estimate_value) == "3")
 })
 
+test_that("dateRange argument works", {
+  skip_on_cran()
+  # Load mock database ----
+  cdm <- cdmEunomia()
+  expect_no_error(summariseClinicalRecords(cdm, "condition_occurrence", dateRange =  as.Date(c("2012-01-01", "2018-01-01"))))
+  expect_message(x<-summariseClinicalRecords(cdm, "drug_exposure", dateRange =  as.Date(c("2012-01-01", "2025-01-01"))))
+  observationRange <- cdm$observation_period |>
+    dplyr::summarise(minobs = min(.data$observation_period_start_date, na.rm = TRUE),
+                     maxobs = max(.data$observation_period_end_date, na.rm = TRUE))
+  expect_no_error(y<- summariseClinicalRecords(cdm, "drug_exposure", dateRange = as.Date(c("2012-01-01", observationRange |>dplyr::pull("maxobs")))))
+  expect_equal(x,y, ignore_attr = TRUE)
+  expect_false(settings(x)$study_period_end==settings(y)$study_period_end)
+  expect_error(summariseClinicalRecords(cdm, "drug_exposure", dateRange =  as.Date(c("2015-01-01", "2014-01-01"))))
+  expect_warning(z<-summariseClinicalRecords(cdm, "drug_exposure", dateRange =  as.Date(c("2020-01-01", "2021-01-01"))))
+  expect_equal(z, omopgenerics::emptySummarisedResult(), ignore_attr = TRUE)
+  expect_equal(summariseClinicalRecords(cdm, "drug_exposure",dateRange = as.Date(c("2012-01-01",NA))), y, ignore_attr = TRUE)
+  checkResultType(z, "summarise_clinical_records")
+  expect_equal(colnames(settings(z)), colnames(settings(x)) )
+
+})
+
+test_that("sample argument works", {
+  skip_on_cran()
+  # Load mock database ----
+  cdm <- cdmEunomia()
+
+  expect_no_error(x<-summariseClinicalRecords(cdm,"drug_exposure", sample = 50))
+  expect_no_error(y<-summariseClinicalRecords(cdm,"drug_exposure"))
+  n <- cdm$drug_exposure |>
+    dplyr::tally()|>
+    dplyr::pull(n)
+  expect_no_error(z<-summariseClinicalRecords(cdm,"drug_exposure",sample = n))
+  expect_equal(y,z)
+  PatientProfiles::mockDisconnect(cdm = cdm)
+})
+
 test_that("tableClinicalRecords() works", {
   skip_on_cran()
   # Load mock database ----
@@ -239,4 +300,40 @@ test_that("tableClinicalRecords() works", {
   PatientProfiles::mockDisconnect(cdm = cdm)
 })
 
+test_that("summariseClinicalRecords() works with mock data", {
+  skip_on_cran()
+  # Load mock database ----
+  cdm <- mockOmopSketch()
 
+  # Check all tables work ----
+  expect_no_error(vo <- summariseClinicalRecords(cdm, "visit_occurrence"))
+  expect_no_error(summariseClinicalRecords(cdm, "drug_exposure"))
+  expect_no_error(summariseClinicalRecords(cdm, "procedure_occurrence"))
+  expect_no_error(summariseClinicalRecords(cdm, "death"))
+
+  PatientProfiles::mockDisconnect(cdm = cdm)
+})
+
+test_that("no tables created", {
+  skip_on_cran()
+  # Load mock database ----
+  cdm <- cdmEunomia()
+
+  startNames <- CDMConnector::listSourceTables(cdm)
+
+  results <- summariseClinicalRecords(cdm = cdm,
+                                       omopTableName = c("drug_exposure", "condition_occurrence"),
+                                       sex = TRUE,
+                                       ageGroup = list(c(0,17),
+                                                       c(18,65),
+                                                       c(66, 100)),
+                                       dateRange = as.Date(c("2012-01-01", "2018-01-01")),
+                                       sample = 100)
+
+  endNames <- CDMConnector::listSourceTables(cdm)
+
+  expect_true(length(setdiff(endNames, startNames)) == 0)
+
+
+  PatientProfiles::mockDisconnect(cdm = cdm)
+})
